<?php

namespace BdevsElement\Widget;

Use \Elementor\Core\Schemes\Typography;
use \Elementor\Group_Control_Background;
use \Elementor\Utils;
use \Elementor\Repeater;
use \Elementor\Control_Media;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Typography;

defined('ABSPATH') || die();

class About extends BDevs_El_Widget
{

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Element widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'about';
    }

    /**
     * Get widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return __('About', 'bdevselement');
    }

    /**
     * Get widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'eicon-single-post';
    }

    public function get_keywords()
    {
        return ['info', 'blurb', 'box', 'about', 'content'];
    }

    /**
     * Register content related controls
     */
    protected function register_content_controls()
    {

        $this->start_controls_section(
            '_section_design_title',
            [
                'label' => __('Design Style', 'bdevselement'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'design_style',
            [
                'label' => __('Design Style', 'bdevselement'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'style_1' => __('Style 1', 'bdevselement'),
                    'style_2' => __('Style 2', 'bdevselement'),
                    'style_3' => __('Style 3', 'bdevselement'),
                    'style_4' => __('Style 4', 'bdevselement'),
                    'style_5' => __('Style 5', 'bdevselement'),
                    'style_6' => __('Style 6', 'bdevselement'),
                    'style_7' => __('Style 7', 'bdevselement'),
                    'style_8' => __('Style 8', 'bdevselement'),
                    'style_9' => __('Style 9', 'bdevselement'),
                    'style_10' => __('Style 10', 'bdevselement'),
                ],
                'default' => 'style_1',
                'frontend_available' => true,
                'style_transfer' => true,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_title',
            [
                'label' => __('Title & Description', 'bdevselement'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'sub_title',
            [
                'label' => __('Sub Title', 'bdevselement'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('bdevs Info Box Sub Title', 'bdevselement'),
                'placeholder' => __('Type Info Box Sub Title', 'bdevselement'),
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'design_style' => ['style_1','style_2','style_3','style_4','style_5','style_6','style_7','style_8','style_9'],
                ],
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => __('Title', 'bdevselement'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('bdevs Info Box Title', 'bdevselement'),
                'placeholder' => __('Type Info Box Title', 'bdevselement'),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'description',
            [
                'label' => __('Description', 'bdevselement'),
                'description' => bdevs_element_get_allowed_html_desc('intermediate'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('bdevs info box description goes here', 'bdevselement'),
                'placeholder' => __('Type info box description', 'bdevselement'),
                'rows' => 5,
                'dynamic' => [
                    'active' => true,
                ],
            ]
        );

        $this->add_control(
            'video_link',
            [
                'label' => __( 'Video Link', 'bdevselement' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __( 'link.com', 'bdevselement' ),
                'placeholder' => __( 'Type Video Link', 'bdevselement' ),
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'design_style' => ['style_8'],
                ],
            ]
        );

        $this->add_control(
            'description2',
            [
                'label' => __('Description 2', 'bdevselement'),
                'description' => bdevs_element_get_allowed_html_desc('intermediate'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('bdevs info box description 2 goes here', 'bdevselement'),
                'placeholder' => __('Type info box description 2', 'bdevselement'),
                'rows' => 5,
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'design_style' => ['style_1','style_5'],
                ],
            ]
        );

        $this->add_control(
            'author_name',
            [
                'label' => __('Author Name', 'bdevselement'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Jose E. Swisher', 'bdevselement'),
                'placeholder' => __('Type Author Name', 'bdevselement'),
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'design_style' => ['style_1'],
                ],
            ]
        );

        $this->add_control(
            'author_designation',
            [
                'label' => __('Author Designation', 'bdevselement'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('CEO & Founder', 'bdevselement'),
                'placeholder' => __('Type Author Designation', 'bdevselement'),
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'design_style' => ['style_1'],
                ],
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' => __('Title HTML Tag', 'bdevselement'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => __('H1', 'bdevselement'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => __('H2', 'bdevselement'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => __('H3', 'bdevselement'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => __('H4', 'bdevselement'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => __('H5', 'bdevselement'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => __('H6', 'bdevselement'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h2',
                'toggle' => false,
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label' => __('Alignment', 'bdevselement'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __('Left', 'bdevselement'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => __('Center', 'bdevselement'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => __('Right', 'bdevselement'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'toggle' => true,
                'selectors' => [
                    '{{WRAPPER}}' => 'text-align: {{VALUE}};'
                ]
            ]
        );

        $this->end_controls_section();

        // img
        $this->start_controls_section(
            '_section_about_image',
            [
                'label' => __('Image', 'bdevselement'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'bg_image',
            [
                'label' => __('Big Image', 'bdevselement'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'image2',
            [
                'label' => __('Image 02', 'bdevselement'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'design_style' => ['style_1','style_5','style_6','style_7'],
                ],
            ]
        );

        $this->add_control(
            'image3',
            [
                'label' => __('Image 03', 'bdevselement'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'design_style' => ['style_6'],
                ],
            ]
        );

        $this->add_control(
            'image4',
            [
                'label' => __('Image 04', 'bdevselement'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'design_style' => ['style_6'],
                ],
            ]
        );

        $this->add_control(
            'author_img',
            [
                'label' => __('Author Image', 'bdevselement'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'design_style' => ['style_1'],
                ],
            ]
        );

        $this->add_control(
            'signature_img',
            [
                'label' => __('Signature Image', 'bdevselement'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'design_style' => ['style_1'],
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'default' => 'large',
                'separator' => 'none',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_features_list',
            [
                'label' => __('Features List', 'bdevselement'),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'design_style' => ['style_2','style_3','style_4','style_5','style_6','style_7','style_8','style_10'],
                ],
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'field_condition',
            [
                'label' => __('Field condition', 'bdevselement'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'style_1' => __('Style 1', 'bdevselement'),
                    'style_2' => __('Style 2', 'bdevselement'),
                    'style_3' => __('Style 3', 'bdevselement'),
                    'style_4' => __('Style 4', 'bdevselement'),
                    'style_5' => __('Style 5', 'bdevselement'),
                    'style_6' => __('Style 6', 'bdevselement'),
                    'style_7' => __('Style 7', 'bdevselement'),
                    'style_8' => __('Style 8', 'bdevselement'),
                ],
                'default' => 'style_1',
                'frontend_available' => true,
                'style_transfer' => true,
            ]
        );

        $repeater->add_control(
            'type',
            [
                'label' => __('Media Type', 'bdevselement'),
                'type' => Controls_Manager::CHOOSE,
                'label_block' => false,
                'options' => [
                    'icon' => [
                        'title' => __('Icon', 'bdevselement'),
                        'icon' => 'fa fa-smile-o',
                    ],
                    'image' => [
                        'title' => __('Image', 'bdevselement'),
                        'icon' => 'fa fa-image',
                    ],
                ],
                'default' => 'icon',
                'toggle' => false,
                'style_transfer' => true,
            ]
        );

        $repeater->add_control(
            'image',
            [
                'label' => __('Image', 'bdevselement'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'type' => 'image'
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'default' => 'medium_large',
                'separator' => 'none',
                'exclude' => [
                    'full',
                    'custom',
                    'large',
                    'shop_catalog',
                    'shop_single',
                    'shop_thumbnail'
                ],
                'condition' => [
                    'type' => 'image'
                ]
            ]
        );

        if (bdevs_element_is_elementor_version('<', '2.6.0')) {
            $repeater->add_control(
                'icon',
                [
                    'label' => __('Icon', 'bdevselement'),
                    'label_block' => true,
                    'type' => Controls_Manager::ICON,
                    'options' => bdevs_element_get_bdevs_element_icons(),
                    'default' => 'fa fa-smile-o',
                    'condition' => [
                        'type' => 'icon'
                    ]
                ]
            );
        } else {
            $repeater->add_control(
                'selected_icon',
                [
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'fas fa-smile-wink',
                        'library' => 'fa-solid',
                    ],
                    'condition' => [
                        'type' => 'icon'
                    ]
                ]
            );
        }

        $repeater->add_control(
            'f_icon_color',
            [
                'label' => __( 'Icon Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.about__icon i' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'field_condition' => ['style_3'],
                ], 
            ]
        );

        $repeater->add_control(
            'f_bg_color',
            [
                'label' => __( 'Slide BG Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.about__item-green' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'field_condition' => ['style_6'],
                ], 
            ]
        );

        $repeater->add_control(
            'f_icon2_color',
            [
                'label' => __( 'Slide Icon Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.about__item-green .about__icon i' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'field_condition' => ['style_6'],
                ], 
            ]
        );

        $repeater->add_control(
            'f_text_color',
            [
                'label' => __( 'Slide Text Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.about__item-green .about__title-2' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'field_condition' => ['style_6'],
                ], 
            ]
        );

        $repeater->add_control(
            'f_desc_color',
            [
                'label' => __( 'Slide Description Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.about__item-green .about__content-2 p' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'field_condition' => ['style_6'],
                ], 
            ]
        );

        $repeater->add_control(
            'f_button_color',
            [
                'label' => __( 'Slide Button Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.about__item-green .about__content-2 .link-btn' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'field_condition' => ['style_6'],
                ], 
            ]
        );

        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'label' => __('Title', 'bdevselement'),
                'placeholder' => __('Type title here', 'bdevselement'),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_control(
            'description',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'label' => __('Description', 'bdevselement'),
                'placeholder' => __('Type Description here', 'bdevselement'),
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'field_condition' => ['style_3','style_4','style_6'],
                ], 
            ]
        );

        $repeater->add_control(
            'slide_link',
            [
                'label' => __( 'Slide Link', 'bdevselement' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __( 'link.com', 'bdevselement' ),
                'placeholder' => __( 'Type Slide Link', 'bdevselement' ),
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'field_condition' => ['style_3','style_6'],
                ],
            ]
        );

        $this->add_control(
            'slides',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '<# print(title || "Carousel Item"); #>',
                'default' => [
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_features_list2',
            [
                'label' => __('Features List 02', 'bdevselement'),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'design_style' => ['style_7','style_8','style_9'],
                ],
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'field_condition',
            [
                'label' => __('Field condition', 'bdevselement'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'style_7' => __('Style 7', 'bdevselement'),
                    'style_8' => __('Style 8', 'bdevselement'),
                    'style_9' => __('Style 9', 'bdevselement'),
                ],
                'default' => 'style_1',
                'frontend_available' => true,
                'style_transfer' => true,
            ]
        );

        $repeater->add_control(
            'type',
            [
                'label' => __('Media Type', 'bdevselement'),
                'type' => Controls_Manager::CHOOSE,
                'label_block' => false,
                'options' => [
                    'icon' => [
                        'title' => __('Icon', 'bdevselement'),
                        'icon' => 'fa fa-smile-o',
                    ],
                    'image' => [
                        'title' => __('Image', 'bdevselement'),
                        'icon' => 'fa fa-image',
                    ],
                ],
                'default' => 'icon',
                'toggle' => false,
                'style_transfer' => true,
            ]
        );

        $repeater->add_control(
            'image',
            [
                'label' => __('Image', 'bdevselement'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'type' => 'image'
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'default' => 'medium_large',
                'separator' => 'none',
                'exclude' => [
                    'full',
                    'custom',
                    'large',
                    'shop_catalog',
                    'shop_single',
                    'shop_thumbnail'
                ],
                'condition' => [
                    'type' => 'image'
                ]
            ]
        );

        if (bdevs_element_is_elementor_version('<', '2.6.0')) {
            $repeater->add_control(
                'icon',
                [
                    'label' => __('Icon', 'bdevselement'),
                    'label_block' => true,
                    'type' => Controls_Manager::ICON,
                    'options' => bdevs_element_get_bdevs_element_icons(),
                    'default' => 'fa fa-smile-o',
                    'condition' => [
                        'type' => 'icon'
                    ]
                ]
            );
        } else {
            $repeater->add_control(
                'selected_icon',
                [
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'fas fa-smile-wink',
                        'library' => 'fa-solid',
                    ],
                    'condition' => [
                        'type' => 'icon'
                    ]
                ]
            );
        }

        $repeater->add_control(
            'number',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'label' => __('Number', 'bdevselement'),
                'placeholder' => __('Type Number here', 'bdevselement'),
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'field_condition' => ['style_7','style_9'],
                ], 
            ]
        );

        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'label' => __('Title', 'bdevselement'),
                'placeholder' => __('Type title here', 'bdevselement'),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_control(
            'f_bg_color',
            [
                'label' => __( 'Slide BG Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.features__item-2' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'field_condition' => ['style_8'],
                ], 
            ]
        );

        $repeater->add_control(
            'f_title_color',
            [
                'label' => __( 'Slide Title Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .features__title-2' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'field_condition' => ['style_8'],
                ], 
            ]
        );

        $repeater->add_control(
            'slide_link',
            [
                'label' => __( 'Slide Link', 'bdevselement' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __( 'link.com', 'bdevselement' ),
                'placeholder' => __( 'Type Slide Link', 'bdevselement' ),
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'field_condition' => ['style_8'],
                ],
            ]
        );

        $repeater->add_control(
            'slide_bottom_text',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'label' => __('Slide Bottom Text', 'bdevselement'),
                'placeholder' => __('Type Bottom Text here', 'bdevselement'),
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'field_condition' => ['style_9'],
                ], 
            ]
        );

        $repeater->add_control(
            'slide_top_text',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'label' => __('Slide Top Text', 'bdevselement'),
                'placeholder' => __('Type Top Text here', 'bdevselement'),
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'field_condition' => ['style_9'],
                ], 
            ]
        );

        $this->add_control(
            'slides2',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '<# print(title || "Carousel Item"); #>',
                'default' => [
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_features_list3',
            [
                'label' => __('Features List 03', 'bdevselement'),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'design_style' => ['style_7'],
                ],
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'field_condition',
            [
                'label' => __('Field condition', 'bdevselement'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'style_1' => __('Style 1', 'bdevselement'),
                ],
                'default' => 'style_1',
                'frontend_available' => true,
                'style_transfer' => true,
            ]
        );

        $repeater->add_control(
            'type',
            [
                'label' => __('Media Type', 'bdevselement'),
                'type' => Controls_Manager::CHOOSE,
                'label_block' => false,
                'options' => [
                    'icon' => [
                        'title' => __('Icon', 'bdevselement'),
                        'icon' => 'fa fa-smile-o',
                    ],
                    'image' => [
                        'title' => __('Image', 'bdevselement'),
                        'icon' => 'fa fa-image',
                    ],
                ],
                'default' => 'icon',
                'toggle' => false,
                'style_transfer' => true,
            ]
        );

        $repeater->add_control(
            'image',
            [
                'label' => __('Image', 'bdevselement'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'type' => 'image'
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'default' => 'medium_large',
                'separator' => 'none',
                'exclude' => [
                    'full',
                    'custom',
                    'large',
                    'shop_catalog',
                    'shop_single',
                    'shop_thumbnail'
                ],
                'condition' => [
                    'type' => 'image'
                ]
            ]
        );

        if (bdevs_element_is_elementor_version('<', '2.6.0')) {
            $repeater->add_control(
                'icon',
                [
                    'label' => __('Icon', 'bdevselement'),
                    'label_block' => true,
                    'type' => Controls_Manager::ICON,
                    'options' => bdevs_element_get_bdevs_element_icons(),
                    'default' => 'fa fa-smile-o',
                    'condition' => [
                        'type' => 'icon'
                    ]
                ]
            );
        } else {
            $repeater->add_control(
                'selected_icon',
                [
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'fas fa-smile-wink',
                        'library' => 'fa-solid',
                    ],
                    'condition' => [
                        'type' => 'icon'
                    ]
                ]
            );
        }

        $repeater->add_control(
            'number',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'label' => __('Number', 'bdevselement'),
                'placeholder' => __('Type Number here', 'bdevselement'),
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'field_condition' => ['style_1'],
                ], 
            ]
        );

        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'label' => __('Title', 'bdevselement'),
                'placeholder' => __('Type title here', 'bdevselement'),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );


        $this->add_control(
            'slides3',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '<# print(title || "Carousel Item"); #>',
                'default' => [
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                ]
            ]
        );

        $this->end_controls_section();


        // Button
        $this->start_controls_section(
            '_section_button',
            [
                'label' => __('Button', 'bdevselement'),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'design_style' => ['style_7','style_8'],
                ],
            ]
        );

        $this->add_control(
            'button_text',
            [
                'label' => __('Text', 'bdevselement'),
                'type' => Controls_Manager::TEXT,
                'default' => __('Button Text', 'bdevselement'),
                'placeholder' => __('Type button text here', 'bdevselement'),
                'label_block' => true,
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'button_link',
            [
                'label' => __('Link', 'bdevselement'),
                'type' => Controls_Manager::URL,
                'placeholder' => __('http://elementor.bdevs.net/', 'bdevselement'),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        if (bdevs_element_is_elementor_version('<', '2.6.0')) {
            $this->add_control(
                'button_icon',
                [
                    'label' => __('Icon', 'bdevselement'),
                    'label_block' => true,
                    'type' => Controls_Manager::ICON,
                    'options' => bdevs_element_get_bdevs_element_icons(),
                    'default' => 'fa fa-angle-right',
                ]
            );

            $condition = ['button_icon!' => ''];
        } else {
            $this->add_control(
                'button_selected_icon',
                [
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'button_icon',
                    'label_block' => true,
                ]
            );
            $condition = ['button_selected_icon[value]!' => ''];
        }

        $this->add_control(
            'button_icon_position',
            [
                'label' => __('Icon Position', 'bdevselement'),
                'type' => Controls_Manager::CHOOSE,
                'label_block' => false,
                'options' => [
                    'before' => [
                        'title' => __('Before', 'bdevselement'),
                        'icon' => 'eicon-h-align-left',
                    ],
                    'after' => [
                        'title' => __('After', 'bdevselement'),
                        'icon' => 'eicon-h-align-right',
                    ],
                ],
                'default' => 'after',
                'toggle' => false,
                'condition' => $condition,
                'style_transfer' => true,
            ]
        );

        $this->add_control(
            'button_icon_spacing',
            [
                'label' => __('Icon Spacing', 'bdevselement'),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'size' => 10
                ],
                'condition' => $condition,
                'selectors' => [
                    '{{WRAPPER}} .btn--icon-before .btn-icon' => 'margin-right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .btn--icon-after .btn-icon' => 'margin-left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Register styles related controls
     */
    protected function register_style_controls()
    {

        $this->start_controls_section(
            '_section_style_content',
            [
                'label' => __( 'Title / Content', 'bdevselement' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Content Padding', 'bdevselement' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'content_background',
                'selector' => '{{WRAPPER}} .bdevs-el-content',
                'exclude' => [
                    'image'
                ]
            ]
        );

        // Title
        $this->add_control(
            '_heading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'bdevselement' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'bdevselement' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Text Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title',
                'selector' => '{{WRAPPER}} .bdevs-el-title',
                'scheme' => Typography::TYPOGRAPHY_2,
            ]
        );

        // Subtitle    
        $this->add_control(
            '_heading_subtitle',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Subtitle', 'bdevselement' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'subtitle_spacing',
            [
                'label' => __( 'Bottom Spacing', 'bdevselement' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-subtitle' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'subtitle_color',
            [
                'label' => __( 'Text Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-subtitle' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle',
                'selector' => '{{WRAPPER}} .bdevs-el-subtitle',
                'scheme' => Typography::TYPOGRAPHY_3,
            ]
        );

        // description
        $this->add_control(
            '_content_description',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Description', 'bdevselement' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'description_spacing',
            [
                'label' => __( 'Bottom Spacing', 'bdevselement' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-content p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'description_color',
            [
                'label' => __( 'Text Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-content p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'description',
                'selector' => '{{WRAPPER}} .bdevs-el-content p',
                'scheme' => Typography::TYPOGRAPHY_4,
            ]
        );


        $this->end_controls_section();


        // list style content
        $this->start_controls_section(
            '_section_style_item',
            [
                'label' => __('List Item', 'bdevselement'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'item_icon_size',
            [
                'label' => __('Size', 'bdevselement'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 300,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-list ul li span i,{{WRAPPER}} .bdevs-el-list ol li::marker,{{WRAPPER}} .bdevs-el-list i' => 'font-size: {{SIZE}}{{UNIT}};',
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'item_typography',
                'selector' => '{{WRAPPER}} .bdevs-el-list ul li span, {{WRAPPER}} .bdevs-el-list ol li, {{WRAPPER}} .bdevs-el-list h3',
                'scheme' => Typography::TYPOGRAPHY_4,
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'item_border',
                'selector' => '{{WRAPPER}} .bdevs-el-list ul li span,{{WRAPPER}} .bdevs-el-list ol li, {{WRAPPER}} .bdevs-el-list i',
            ]
        );

        $this->add_control(
            'item_border_radius',
            [
                'label' => __('Border Radius', 'bdevselement'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-list ul li span i,{{WRAPPER}} .bdevs-el-list ol li::marker, {{WRAPPER}} .bdevs-el-list i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'item_box_shadow',
                'selector' => '{{WRAPPER}} .bdevs-el-list ul li span i,{{WRAPPER}} .bdevs-el-list ol li::marker, {{WRAPPER}} .bdevs-el-list i',
            ]
        );

        $this->add_control(
            'hr_2',
            [
                'type' => Controls_Manager::DIVIDER,
                'style' => 'thick',
            ]
        );

        $this->start_controls_tabs('_lits_tabs_button');

        $this->start_controls_tab(
            '_list_tab_button_normal',
            [
                'label' => __('Normal', 'bdevselement'),
            ]
        );

        $this->add_control(
            'list_item_link_color_2',
            [
                'label' => __('Text Color', 'bdevselement'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-list ul li span i,{{WRAPPER}} .bdevs-el-list ol li::marker,{{WRAPPER}} .bdevs-el-list ol li, {{WRAPPER}} .bdevs-el-list h3, {{WRAPPER}} .bdevs-el-list i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'list_item_border_color_2',
            [
                'label' => __('Border Color', 'bdevselement'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-list ul li span i,{{WRAPPER}} .bdevs-el-list ol li::marker,{{WRAPPER}} .bdevs-el-list ol li, {{WRAPPER}} .bdevs-el-list h3, {{WRAPPER}} .bdevs-el-list i' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'list_item_bg_color_2',
            [
                'label' => __('Background Color', 'bdevselement'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-list ul li span i,{{WRAPPER}} .bdevs-el-list ol li::marker,{{WRAPPER}} .bdevs-el-list ol li, {{WRAPPER}} .bdevs-el-list h3, {{WRAPPER}} .bdevs-el-list i' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'list_icon_translate_2',
            [
                'label' => __('Icon Translate X', 'bdevselement'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-list ul li span i,{{WRAPPER}} .bdevs-el-list ol li::marker,{{WRAPPER}} .bdevs-el-list ol li, {{WRAPPER}} .bdevs-el-list h3, {{WRAPPER}} .bdevs-el-list i' => '-webkit-transform: translateX(calc(-1 * {{SIZE}}{{UNIT}})); transform: translateX(calc(-1 * {{SIZE}}{{UNIT}}));',
                    '{{WRAPPER}} .bdevs-el-list ul li span i,{{WRAPPER}} .bdevs-el-list ol li::marker,{{WRAPPER}} .bdevs-el-list ol li, {{WRAPPER}} .bdevs-el-list h3, {{WRAPPER}} .bdevs-el-list i' => '-webkit-transform: translateX({{SIZE}}{{UNIT}}); transform: translateX({{SIZE}}{{UNIT}});',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            '_list_tab_button_hover',
            [
                'label' => __('Hover', 'bdevselement'),
            ]
        );

        $this->add_control(
            'list_link_hover_color',
            [
                'label' => __('Text Color', 'bdevselement'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-list ul li:hover span i,{{WRAPPER}} .capabilities__list ol li::marker,,{{WRAPPER}} .capabilities__list ol li, {{WRAPPER}} .achievement__item h3:hover, {{WRAPPER}} .achievement__item i:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'list_border_hover_color',
            [
                'label' => __('Border Color', 'bdevselement'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-list ul li:hover span i,{{WRAPPER}} .bdevs-el-list ol li::marker,,{{WRAPPER}} .bdevs-el-list ol li, {{WRAPPER}} .bdevs-el-list h3:hover, {{WRAPPER}} .bdevs-el-list i:hover' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'list_hover_bg_color',
            [
                'label' => __('Background Color', 'bdevselement'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-list ul li:hover span i, {{WRAPPER}} .bdevs-el-list ul li:hover span i,{{WRAPPER}} .capabilities__list ol li::marker,,{{WRAPPER}} .capabilities__list ol li, {{WRAPPER}} .bdevs-el-list h3:hover, {{WRAPPER}} .bdevs-el-list i:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'list_hover_icon_translate',
            [
                'label' => __('Icon Translate X', 'bdevselement'),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'size' => 0
                ],
                'range' => [
                    'px' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-list ul li:hover span i,{{WRAPPER}} .bdevs-el-list ol li::marker,,{{WRAPPER}} .bdevs-el-list ol li, {{WRAPPER}} .bdevs-el-list h3:hover, {{WRAPPER}} .bdevs-el-list i:hover' => '-webkit-transform: translateX(calc(-1 * {{SIZE}}{{UNIT}})); transform: translateX(calc(-1 * {{SIZE}}{{UNIT}}));',
                    '{{WRAPPER}} .bdevs-el-list ul li:hover span i,{{WRAPPER}} .bdevs-el-list ol li::marker,,{{WRAPPER}} .bdevs-el-list ol li, {{WRAPPER}} .bdevs-el-list h3:hover, {{WRAPPER}} .bdevs-el-list i:hover' => '-webkit-transform: translateX({{SIZE}}{{UNIT}}); transform: translateX({{SIZE}}{{UNIT}});',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();
        
        // Button 1 style
        $this->start_controls_section(
            '_section_style_button',
            [
                'label' => __( 'Button', 'bdevselement' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'button_padding',
            [
                'label' => __( 'Padding', 'bdevselement' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'button_typography',
                'selector' => '{{WRAPPER}} .bdevs-el-btn',
                'scheme' => Typography::TYPOGRAPHY_4,
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'button_border',
                'selector' => '{{WRAPPER}} .bdevs-el-btn',
            ]
        );

        $this->add_control(
            'button_border_radius',
            [
                'label' => __( 'Border Radius', 'bdevselement' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'button_box_shadow',
                'selector' => '{{WRAPPER}} .bdevs-el-btn',
            ]
        );

        $this->add_control(
            'hr',
            [
                'type' => Controls_Manager::DIVIDER,
                'style' => 'thick',
            ]
        );

        $this->start_controls_tabs( '_tabs_button' );

        $this->start_controls_tab(
            '_tab_button_normal',
            [
                'label' => __( 'Normal', 'bdevselement' ),
            ]
        );

        $this->add_control(
            'button_color',
            [
                'label' => __( 'Text Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-btn' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_bg_color',
            [
                'label' => __( 'Background Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-btn' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            '_tab_button_hover',
            [
                'label' => __( 'Hover', 'bdevselement' ),
            ]
        );

        $this->add_control(
            'button_hover_color',
            [
                'label' => __( 'Text Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-btn:hover, {{WRAPPER}} .bdevs-el-btn:focus' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_hover_bg_color',
            [
                'label' => __( 'Background Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-btn:hover, {{WRAPPER}} .bdevs-el-btn:focus' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_hover_border_color',
            [
                'label' => __( 'Border Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'button_border_border!' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .bdevs-el-btn:hover, {{WRAPPER}} .bdevs-el-btn:focus' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();


    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $title = bdevs_element_kses_basic($settings['title']);
        ?>
        <?php if ($settings['design_style'] === 'style_10'):
        if (!empty($settings['bg_image']['id'])) {
            $bg_image = wp_get_attachment_image_url($settings['bg_image']['id'], $settings['thumbnail_size']);
        }

        $this->add_render_attribute('title', 'class', ' bdevs-el-title');

        ?>

        <div class="portfolio__details-goal">
           <div class="row">
              <div class="col-xxl-6 col-xl-6 col-lg-6">
                 <div class="portfolio__details-goal-thumb w-img">
                    <img src="<?php echo esc_url($bg_image); ?>" alt="img">
                 </div>
              </div>
              <div class="col-xxl-6 col-xl-6 col-lg-6">
                 <div class="portfolio__details-goal-content pl-25 pt-35">
                    <div class="portfolio__details-text">

                       <?php if (!empty($settings['title'])): ?>
                       <h3 class="portfolio__details-title"><?php echo bdevs_element_kses_intermediate($settings['title']); ?></h3>
                       <?php endif; ?>

                        <?php if (!empty($settings['description'])): ?>
                       <p>
                        <?php echo bdevs_element_kses_intermediate($settings['description']); ?>
                        </p>
                       <?php endif; ?>

                       <div class="portfolio__details-goal-features">
                          <ul>
                             <?php foreach ($settings['slides'] as $slide): ?>
                             <li class="d-flex align-items-center">
                                <div class="icon mr-20">
                                    <?php if ($slide['type'] === 'image' && ($slide['image']['url'] || $slide['image']['id'])) :
                                        $this->get_render_attribute_string('image');
                                        $slide['hover_animation'] = 'disable-animation'; ?>
                                        <?php echo Group_Control_Image_Size::get_attachment_image_html($slide, 'thumbnail', 'image'); ?>
                                    <?php elseif (!empty($slide['icon']) || !empty($slide['selected_icon']['value'])) : ?>
                                        <?php bdevs_element_render_icon($slide, 'icon', 'selected_icon'); ?>
                                    <?php endif; ?>
                                </div>

                                <?php if (!empty($slide['title'])) : ?>
                                <div class="text">
                                 <p><?php echo bdevs_element_kses_basic($slide['title']); ?></p>
                                </div>
                                <?php endif; ?>
                             </li>
                             <?php endforeach; ?>
                          </ul>
                       </div>
                    </div>
                 </div>
              </div>
           </div>
        </div>

    <?php elseif ($settings['design_style'] === 'style_9'):

        if (!empty($settings['bg_image']['id'])) {
            $bg_image = wp_get_attachment_image_url($settings['bg_image']['id'], $settings['thumbnail_size']);
        }

        $this->add_render_attribute('title', 'class', 'section__title section__title-2 bdevs-el-title');

        ?>

        <section class="counter__area grey-bg pt-340 pb-100 p-relative z-index-1">
            <div class="counter__bg" data-background="<?php echo esc_url($bg_image); ?>"></div>
            <div class="container">
               <div class="counter__wrapper p-relative z-index-1">
                  <div class="row">
                    <?php foreach ($settings['slides2'] as $slide): ?>
                    <div class="col-xxl-3 col-xl-3 col-lg-4 col-md-4 counter-col-wrapper">
                        <?php if (!empty($slide['slide_top_text'])) : ?>
                        <div class="counter__item counter__item-text text-center yellow-bg mb-30">
                          <h3 class="counter__text"><?php echo bdevs_element_kses_basic($slide['slide_top_text']); ?></h3>
                        </div>
                        <?php endif; ?>

                        <div class="counter__item-wrapper">
                           <div class="counter__item text-center white-bg mb-30">
                              <div class="counter__icon mb-15">
                                <?php if ($slide['type'] === 'image' && ($slide['image']['url'] || $slide['image']['id'])) :
                                    $this->get_render_attribute_string('image');
                                    $slide['hover_animation'] = 'disable-animation'; ?>
                                    <?php echo Group_Control_Image_Size::get_attachment_image_html($slide, 'thumbnail', 'image'); ?>
                                <?php elseif (!empty($slide['icon']) || !empty($slide['selected_icon']['value'])) : ?>
                                    <?php bdevs_element_render_icon($slide, 'icon', 'selected_icon'); ?>
                                <?php endif; ?>
                              </div>
                              <div class="counter__content">
                                 <?php if (!empty($slide['number'])) : ?>
                                 <h3><span class="counter"><?php echo bdevs_element_kses_basic($slide['number']); ?></span></h3>
                                 <?php endif; ?>

                                 <?php if (!empty($slide['title'])) : ?>
                                 <p><?php echo bdevs_element_kses_basic($slide['title']); ?></p>
                                 <?php endif; ?>
                              </div>
                           </div>
                        </div>
                        <?php if (!empty($slide['slide_bottom_text'])) : ?>
                        <div class="counter__item counter__item-text text-center green-bg-2 mb-30">
                          <h3 class="counter__text white-color"><?php echo bdevs_element_kses_basic($slide['slide_bottom_text']); ?></h3>
                        </div>
                        <?php endif; ?>
                    </div>
                    <?php endforeach; ?>
                  </div>
               </div>
            </div>
        </section>

    <?php elseif ($settings['design_style'] === 'style_8'):

        if (!empty($settings['bg_image']['id'])) {
            $bg_image = wp_get_attachment_image_url($settings['bg_image']['id'], $settings['thumbnail_size']);
        }

        $this->add_render_attribute('title', 'class', 'section__title section__title-2 bdevs-el-title');

        $this->add_render_attribute('button', 'class', 'r-btn r-btn-border-2 bdevs-el-btn');
        $this->add_render_attribute('button', 'data-wow-delay', '');
        $this->add_link_attributes('button', $settings['button_link']);

        ?>

        <section class="features__area">
            <div class="container">
               <div class="row">
                  <div class="col-xxl-5 col-xl-6 col-lg-7">
                     <div class="features__wrapper-2 pr-55">
                        <div class="section__title-wrapper-2 mb-25">
                           <?php if (!empty($settings['sub_title'])): ?>
                           <span class="section__title-pre section__title-pre-2 bdevs-el-subtitle"><?php echo bdevs_element_kses_intermediate($settings['sub_title']); ?></span>
                           <?php endif; ?>

                            <?php printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['title_tag']),
                                $this->get_render_attribute_string('title'),
                                $title
                            ); ?>
                        </div>

                        <?php if (!empty($settings['description'])): ?>
                        <p><?php echo bdevs_element_kses_intermediate($settings['description']); ?></p>
                        <?php endif; ?>

                        <div class="features__list mb-35">
                           <ul>
                              <?php foreach ($settings['slides'] as $slide): ?>
                              <li class="d-flex align-items-center">
                                 <div class="features__list-icon mr-20">
                                    <?php if ($slide['type'] === 'image' && ($slide['image']['url'] || $slide['image']['id'])) :
                                        $this->get_render_attribute_string('image');
                                        $slide['hover_animation'] = 'disable-animation'; ?>
                                        <?php echo Group_Control_Image_Size::get_attachment_image_html($slide, 'thumbnail', 'image'); ?>
                                    <?php elseif (!empty($slide['icon']) || !empty($slide['selected_icon']['value'])) : ?>
                                        <?php bdevs_element_render_icon($slide, 'icon', 'selected_icon'); ?>
                                    <?php endif; ?>
                                 </div>
                                 <?php if (!empty($slide['title'])) : ?>
                                 <div class="features__list-text">
                                    <p><?php echo bdevs_element_kses_basic($slide['title']); ?></p>
                                 </div>
                                 <?php endif; ?>
                              </li>
                              <?php endforeach; ?>
                           </ul>
                        </div>
                          
                        <div class="features__btn">
                            <?php if ($settings['button_text'] && ((empty($settings['button_selected_icon']) || empty($settings['button_selected_icon']['value'])) && empty($settings['button_icon']))) :
                                printf('<a %1$s href="%3$s">%2$s</a>',
                                    $this->get_render_attribute_string('button'),
                                    esc_html($settings['button_text']),
                                    esc_url($settings['button_link']['url'])
                                );
                            elseif (empty($settings['button_text']) && ((!empty($settings['button_selected_icon']) || empty($settings['button_selected_icon']['value'])) || !empty($settings['button_icon']))) : ?>
                                <a <?php $this->print_render_attribute_string('button'); ?>><?php bdevs_element_render_icon($settings, 'button_icon', 'button_selected_icon'); ?></a>
                            <?php elseif ($settings['button_text'] && ((!empty($settings['button_selected_icon']) || empty($settings['button_selected_icon']['value'])) || !empty($settings['button_icon']))) :
                                if ($settings['button_icon_position'] === 'before'): ?>
                                    <a <?php $this->print_render_attribute_string('button'); ?>><?php bdevs_element_render_icon($settings, 'button_icon', 'button_selected_icon', ['class' => 'bdevs-btn-icon']); ?>
                                        <span><?php echo esc_html($settings['button_text']); ?></span></a>
                                <?php
                                else: ?>
                                    <a <?php $this->print_render_attribute_string('button'); ?>>
                                        <span><?php echo esc_html($settings['button_text']); ?></span>
                                        <?php bdevs_element_render_icon($settings, 'button_icon', 'button_selected_icon', ['class' => 'bdevs-btn-icon']); ?>
                                    </a>
                                <?php
                                endif;
                            endif; ?>
                        </div>
                     </div>
                  </div>

                  <div class="col-xxl-7 col-xl-6">
                     <div class="features__item-wrapper p-relative">
                        <?php foreach ($settings['slides2'] as $slide): ?>
                        <div class="features__item-2  elementor-repeater-item-<?php echo esc_attr($slide['_id']); ?> text-center">
                           <div class="features__icon-2 mb-15">
                              <span>
                                    <?php if ($slide['type'] === 'image' && ($slide['image']['url'] || $slide['image']['id'])) :
                                        $this->get_render_attribute_string('image');
                                        $slide['hover_animation'] = 'disable-animation'; ?>
                                        <?php echo Group_Control_Image_Size::get_attachment_image_html($slide, 'thumbnail', 'image'); ?>
                                    <?php elseif (!empty($slide['icon']) || !empty($slide['selected_icon']['value'])) : ?>
                                        <?php bdevs_element_render_icon($slide, 'icon', 'selected_icon'); ?>
                                    <?php endif; ?>
                              </span>
                           </div>

                           <?php if (!empty($slide['title'])) : ?>
                           <h3 class="features__title features__title-2">
                              <a href="<?php echo esc_url( $slide['slide_link'] ); ?>"><?php echo bdevs_element_kses_basic($slide['title']); ?></a>
                           </h3>
                           <?php endif; ?>
                        </div>
                        <?php endforeach; ?>
                        <div class="features__shape">
                           <img class="features__shape-1" src="<?php echo get_template_directory_uri(); ?>/assets/img/features/02/about-shape-1.png" alt="img">
                        </div>

                        <?php if (!empty($bg_image)): ?>
                        <div class="features__video">
                           <div class="features__video-triangle">
                              <div class="features__video-thumb">
                                 <img src="<?php echo esc_url($bg_image); ?>" alt="img">
                                 <a href="<?php echo esc_url( $settings['video_link'] ); ?>" class="play-btn popup-video"><i class="fas fa-play"></i></a>
                              </div>
                           </div>
                        </div>
                        <?php endif; ?>
                     </div>
                  </div>
               </div>
            </div>
        </section>


    <?php elseif ($settings['design_style'] === 'style_7'):

        if (!empty($settings['bg_image']['id'])) {
            $bg_image = wp_get_attachment_image_url($settings['bg_image']['id'], $settings['thumbnail_size']);
        }

        if (!empty($settings['image2']['id'])) {
            $image2 = wp_get_attachment_image_url($settings['image2']['id'], $settings['thumbnail_size']);
        }

        $this->add_render_attribute('title', 'class', 'section__title section__title-2 bdevs-el-title');
        $this->add_render_attribute('title', 'data-wow-delay', '');

        $this->add_render_attribute('button', 'class', 'r-btn r-btn-yellow bdevs-el-btn');
        $this->add_render_attribute('button', 'data-wow-delay', '1.2s');
        $this->add_link_attributes('button', $settings['button_link']);

        ?>

        <section class="counter__area pb-100 p-relative pt-95 z-index-1">
            <?php if (!empty($bg_image)): ?>
            <div class="counter__bg" data-background="<?php echo esc_url($bg_image); ?>"></div>
            <?php endif; ?>
            <div class="container">
               <div class="row">
                  <div class="col-xxl-5 col-xl-5 col-lg-6 ">
                     <div class="counter__wrapper-3 pt-50 pr-50">
                        <div class="section__title-wrapper mb-80 ">
                           <?php if (!empty($settings['sub_title'])): ?>
                           <span class="section__title-pre section__title-pre-3 bdevs-el-subtitle"><?php echo bdevs_element_kses_intermediate($settings['sub_title']); ?></span>
                           <?php endif; ?>

                            <?php printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['title_tag']),
                                $this->get_render_attribute_string('title'),
                                $title
                            ); ?>
                        </div>
                        <div class="counter__about d-sm-flex align-items-center mb-30">
                           <?php if (!empty($image2)): ?>
                           <div class="counter__about-thumb mr-30">
                              <img src="<?php echo esc_url($image2); ?>" alt="img">
                           </div>
                           <?php endif; ?>

                            <?php if (!empty($settings['description'])): ?>
                            <div class="counter__about-text bdevs-el-content">
                                <p><?php echo bdevs_element_kses_intermediate($settings['description']); ?></p>
                            </div>
                            <?php endif; ?>
                        </div>

                        <div class="counter__list mb-45">
                           <ul>
                              <?php foreach ($settings['slides'] as $slide): ?>
                              <li class="d-flex align-items-center">
                                 <div class="counter__list-icon mr-20">
                                    <?php if ($slide['type'] === 'image' && ($slide['image']['url'] || $slide['image']['id'])) :
                                        $this->get_render_attribute_string('image');
                                        $slide['hover_animation'] = 'disable-animation'; ?>
                                        <?php echo Group_Control_Image_Size::get_attachment_image_html($slide, 'thumbnail', 'image'); ?>
                                    <?php elseif (!empty($slide['icon']) || !empty($slide['selected_icon']['value'])) : ?>
                                        <?php bdevs_element_render_icon($slide, 'icon', 'selected_icon'); ?>
                                    <?php endif; ?>
                                 </div>

                                 <?php if (!empty($slide['title'])) : ?>
                                 <div class="counter__list-content">
                                    <p><?php echo bdevs_element_kses_basic($slide['title']); ?></p>
                                 </div>
                                 <?php endif; ?>
                              </li>
                              <?php endforeach; ?>
                           </ul>
                        </div>

                        <?php if ($settings['button_text'] && ((empty($settings['button_selected_icon']) || empty($settings['button_selected_icon']['value'])) && empty($settings['button_icon']))) :
                            printf('<a %1$s href="%3$s">%2$s</a>',
                                $this->get_render_attribute_string('button'),
                                esc_html($settings['button_text']),
                                esc_url($settings['button_link']['url'])
                            );
                        elseif (empty($settings['button_text']) && ((!empty($settings['button_selected_icon']) || empty($settings['button_selected_icon']['value'])) || !empty($settings['button_icon']))) : ?>
                            <a <?php $this->print_render_attribute_string('button'); ?>><?php bdevs_element_render_icon($settings, 'button_icon', 'button_selected_icon'); ?></a>
                        <?php elseif ($settings['button_text'] && ((!empty($settings['button_selected_icon']) || empty($settings['button_selected_icon']['value'])) || !empty($settings['button_icon']))) :
                            if ($settings['button_icon_position'] === 'before'): ?>
                                <a <?php $this->print_render_attribute_string('button'); ?>><?php bdevs_element_render_icon($settings, 'button_icon', 'button_selected_icon', ['class' => 'bdevs-btn-icon']); ?>
                                    <span><?php echo esc_html($settings['button_text']); ?></span></a>
                            <?php
                            else: ?>
                                <a <?php $this->print_render_attribute_string('button'); ?>>
                                    <span><?php echo esc_html($settings['button_text']); ?></span>
                                    <?php bdevs_element_render_icon($settings, 'button_icon', 'button_selected_icon', ['class' => 'bdevs-btn-icon']); ?>
                                </a>
                            <?php
                            endif;
                        endif; ?>
                     </div>
                  </div>
                  <div class="col-xxl-3 offset-xxl-1 col-xl-3 offset-xl-1 col-lg-3 offset-lg-0 col-md-4 offset-md-2 col-sm-6">
                     <div class="counter__item-wrapper mt-115">
                        <?php foreach ($settings['slides2'] as $slide): ?>
                        <div class="counter__item counter__item-3 text-center white-bg mb-30">
                           <div class="counter__icon mb-15">
                                <?php if ($slide['type'] === 'image' && ($slide['image']['url'] || $slide['image']['id'])) :
                                    $this->get_render_attribute_string('image');
                                    $slide['hover_animation'] = 'disable-animation'; ?>
                                    <?php echo Group_Control_Image_Size::get_attachment_image_html($slide, 'thumbnail', 'image'); ?>
                                <?php elseif (!empty($slide['icon']) || !empty($slide['selected_icon']['value'])) : ?>
                                    <?php bdevs_element_render_icon($slide, 'icon', 'selected_icon'); ?>
                                <?php endif; ?>
                           </div>
                           <div class="counter__content">
                              <?php if (!empty($slide['number'])) : ?>
                              <h3><span class="counter"><?php echo bdevs_element_kses_basic($slide['number']); ?></span></h3>
                              <?php endif; ?>

                              <?php if (!empty($slide['title'])) : ?>
                              <p><?php echo bdevs_element_kses_basic($slide['title']); ?></p>
                              <?php endif; ?>
                           </div>
                        </div>
                        <?php endforeach; ?>
                     </div>
                  </div>
                  <div class="col-xxl-3 col-xl-3 col-lg-3 col-md-4 col-sm-6">
                     <div class="counter__item-wrapper">
                        <?php foreach ($settings['slides3'] as $slide): ?>
                        <div class="counter__item counter__item-3 text-center white-bg mb-30">
                           <div class="counter__icon mb-15">
                                <?php if ($slide['type'] === 'image' && ($slide['image']['url'] || $slide['image']['id'])) :
                                    $this->get_render_attribute_string('image');
                                    $slide['hover_animation'] = 'disable-animation'; ?>
                                    <?php echo Group_Control_Image_Size::get_attachment_image_html($slide, 'thumbnail', 'image'); ?>
                                <?php elseif (!empty($slide['icon']) || !empty($slide['selected_icon']['value'])) : ?>
                                    <?php bdevs_element_render_icon($slide, 'icon', 'selected_icon'); ?>
                                <?php endif; ?>
                           </div>
                           <div class="counter__content">
                              <?php if (!empty($slide['number'])) : ?>
                              <h3><span class="counter"><?php echo bdevs_element_kses_basic($slide['number']); ?></span></h3>
                              <?php endif; ?>

                              <?php if (!empty($slide['title'])) : ?>
                              <p><?php echo bdevs_element_kses_basic($slide['title']); ?></p>
                              <?php endif; ?>
                           </div>
                        </div>
                        <?php endforeach; ?>
                     </div>
                  </div>
               </div>
            </div>
        </section>

    <?php elseif ($settings['design_style'] === 'style_6'):

        if (!empty($settings['bg_image']['id'])) {
            $bg_image = wp_get_attachment_image_url($settings['bg_image']['id'], $settings['thumbnail_size']);
        }

        if (!empty($settings['image2']['id'])) {
            $image2 = wp_get_attachment_image_url($settings['image2']['id'], $settings['thumbnail_size']);
        }

        if (!empty($settings['image3']['id'])) {
            $image3 = wp_get_attachment_image_url($settings['image3']['id'], $settings['thumbnail_size']);
        }

        if (!empty($settings['image4']['id'])) {
            $image4 = wp_get_attachment_image_url($settings['image4']['id'], $settings['thumbnail_size']);
        }

        $this->add_render_attribute('title', 'class', 'section__title section__title-2 bdevs-el-title');
        $this->add_render_attribute('title', 'data-wow-delay', '');

        ?>

        <section class="about__area p-relative z-index-1">
            <div class="container">
               <div class="row">
                  <div class="col-xxl-7 col-xl-6 col-lg-6">
                     <div class="row">
                        <?php if (!empty($bg_image)): ?>
                        <div class="col-xxl-7 col-xl-7 col-lg-7 col-md-7 col-sm-6">
                           <div class="about__thumb w-img mb-30">
                              <img class="about-1" src="<?php echo esc_url($bg_image); ?>" alt="img">
                           </div>
                        </div>
                        <?php endif; ?>
                        <?php if (!empty($image2)): ?>
                        <div class="col-xxl-5 col-xl-5 col-lg-5 col-md-5 col-sm-6">
                           <div class="about__thumb mt-45 pr-50 mb-30 w-img">
                              <img class="about-2" src="<?php echo esc_url($image2); ?>" alt="img">
                           </div>
                        </div>
                        <?php endif; ?>
                        <?php if (!empty($image3)): ?>
                        <div class="col-xxl-5 col-xl-5 col-lg-5 col-md-5 col-sm-6">
                           <div class="about__thumb pl-50 mb-30 w-img d-none d-sm-block">
                              <img class="about-3" src="<?php echo esc_url($image3); ?>" alt="img">
                           </div>
                        </div>
                        <?php endif; ?>
                        <?php if (!empty($image4)): ?>
                        <div class="col-xxl-7 col-xl-7 col-lg-7 col-md-7 col-sm-6">
                           <div class="about__thumb about-mt--130 mb-30 w-img d-none d-sm-block">
                              <img class="about-4" src="<?php echo esc_url($image4); ?>" alt="img">
                           </div>
                        </div>
                        <?php endif; ?>
                     </div>
                  </div>
                  <div class="col-xxl-5 col-xl-6 col-lg-6">
                     <div class="about__wrapper-2 pl-20 ">
                        <div class="section__title-wrapper-2 mb-25">
                           <?php if (!empty($settings['sub_title'])): ?>
                           <span class="section__title-pre section__title-pre-2 bdevs-el-subtitle"><?php echo bdevs_element_kses_intermediate($settings['sub_title']); ?></span>
                           <?php endif; ?>

                            <?php printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['title_tag']),
                                $this->get_render_attribute_string('title'),
                                $title
                            ); ?>
                        </div>

                        <?php if (!empty($settings['description'])): ?>
                        <p><?php echo bdevs_element_kses_intermediate($settings['description']); ?></p>
                        <?php endif; ?>

                        <div class="about__item-wrapper">
                           <div class="row">
                              <?php foreach ($settings['slides'] as $slide): ?>
                              <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-6">
                                 <div class="about__item about__item-green white-bg text-center mb-30 elementor-repeater-item-<?php echo esc_attr($slide['_id']); ?>">
                                    <div class="about__icon mb-15">
                                        <?php if ($slide['type'] === 'image' && ($slide['image']['url'] || $slide['image']['id'])) :
                                            $this->get_render_attribute_string('image');
                                            $slide['hover_animation'] = 'disable-animation'; ?>
                                            <?php echo Group_Control_Image_Size::get_attachment_image_html($slide, 'thumbnail', 'image'); ?>
                                        <?php elseif (!empty($slide['icon']) || !empty($slide['selected_icon']['value'])) : ?>
                                            <?php bdevs_element_render_icon($slide, 'icon', 'selected_icon'); ?>
                                        <?php endif; ?>
                                    </div>
                                    <div class="about__content-2">
                                       <?php if (!empty($slide['title'])) : ?>
                                       <h3 class="about__title-2">
                                          <a href="<?php echo esc_url( $slide['slide_link'] ); ?>"><?php echo bdevs_element_kses_basic($slide['title']); ?></a>
                                       </h3>
                                       <?php endif; ?>

                                       <?php if (!empty($slide['description'])) : ?>
                                       <p><?php echo bdevs_element_kses_basic($slide['description']); ?></p>
                                       <?php endif; ?>

                                       <a href="<?php echo esc_url( $slide['slide_link'] ); ?>" class="link-btn">
                                          <i class="fal fa-arrow-right"></i>
                                          <i class="fal fa-arrow-right"></i>
                                       </a>
                                    </div>
                                 </div>
                              </div>
                              <?php endforeach; ?>
                           </div>
                        </div>
                     </div>
                  </div>
               </div>
            </div>
        </section>

    <?php elseif ($settings['design_style'] === 'style_5'):

        if (!empty($settings['bg_image']['id'])) {
            $bg_image = wp_get_attachment_image_url($settings['bg_image']['id'], $settings['thumbnail_size']);
        }

        if (!empty($settings['image2']['id'])) {
            $image2 = wp_get_attachment_image_url($settings['image2']['id'], $settings['thumbnail_size']);
        }

        $this->add_render_attribute('title', 'class', 'section__title section__title-2 section__title-white bdevs-el-title');
        $this->add_render_attribute('title', 'data-wow-delay', '');

        ?>

        <section class="about__area pt-255 green-bg-2 p-relative z-index-1">
            <div class="about__bg" data-background="<?php echo esc_url($bg_image); ?>"></div>
            <div class="container">
               <div class="row">
                  <div class="col-xxl-6 col-xl-6 col-lg-6">
                    <?php if (!empty($image2)): ?>
                     <div class="about__img w-img">
                        <img src="<?php echo esc_url($image2); ?>" alt="img">
                     </div>
                     <?php endif; ?>
                  </div>
                  <div class="col-xxl-5 offset-xxl-1 col-xl-6 col-lg-6">
                     <div class="about__wrapper-3">
                        <div class="section__title-wrapper mb-35">
                           <?php if (!empty($settings['sub_title'])): ?>
                           <span class="section__title-pre section__title-pre-3 section__title-pre-yellow yellow bdevs-el-subtitle"><?php echo bdevs_element_kses_intermediate($settings['sub_title']); ?></span>
                           <?php endif; ?>

                            <?php printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['title_tag']),
                                $this->get_render_attribute_string('title'),
                                $title
                            ); ?>
                        </div>

                        <?php if (!empty($settings['description'])): ?>
                        <p class="about__quote"><?php echo bdevs_element_kses_intermediate($settings['description']); ?></p>
                        <?php endif; ?>

                        <?php if (!empty($settings['description2'])): ?>
                        <p class="ab-text"><?php echo bdevs_element_kses_intermediate($settings['description2']); ?></p>
                        <?php endif; ?>

                        <div class="about__features">
                           <ul>
                              <?php foreach ($settings['slides'] as $slide): ?>
                              <li class="d-flex align-items-center">
                                 <div class="about__features-icon mr-15">
                                    <?php if ($slide['type'] === 'image' && ($slide['image']['url'] || $slide['image']['id'])) :
                                        $this->get_render_attribute_string('image');
                                        $slide['hover_animation'] = 'disable-animation'; ?>
                                        <?php echo Group_Control_Image_Size::get_attachment_image_html($slide, 'thumbnail', 'image'); ?>
                                    <?php elseif (!empty($slide['icon']) || !empty($slide['selected_icon']['value'])) : ?>
                                        <?php bdevs_element_render_icon($slide, 'icon', 'selected_icon'); ?>
                                    <?php endif; ?>
                                 </div>
                                 <div class="about__features-content">
                                    <?php if (!empty($slide['title'])) : ?>
                                    <h5>
                                        <?php echo bdevs_element_kses_basic($slide['title']); ?>
                                    </h5>
                                    <?php endif; ?>
                                 </div>
                              </li>
                              <?php endforeach; ?>
                           </ul>
                        </div>
                     </div>
                  </div>
               </div>
            </div>
        </section>

    <?php elseif ($settings['design_style'] === 'style_4'):

        if (!empty($settings['bg_image']['id'])) {
            $bg_image = wp_get_attachment_image_url($settings['bg_image']['id'], $settings['thumbnail_size']);
        }

        $this->add_render_attribute('title', 'class', 'section__title section__title-2 bdevs-el-title');
        $this->add_render_attribute('title', 'data-wow-delay', '');

        ?>

        <section class="why__area">
            <div class="container">
               <div class="row">
                  <div class="col-xxl-7 col-xl-6 col-lg-6">
                    <?php if (!empty($bg_image)): ?>
                     <div class="why__thumb why__thumb-2 pr-70 w-img">
                        <img src="<?php echo esc_url($bg_image); ?>" alt="img">
                     </div>
                     <?php endif; ?>
                  </div>
                  <div class="col-xxl-5 col-xl-6 col-lg-6">
                     <div class="why__wrapper-2 pt-25 pr-30">
                        <div class="section__title-wrapper-2 mb-30">
                            <?php if (!empty($settings['sub_title'])): ?>
                           <span class="section__title-pre section__title-pre-2 bdevs-el-subtitle"><?php echo bdevs_element_kses_intermediate($settings['sub_title']); ?></span>
                            <?php endif; ?>

                            <?php printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['title_tag']),
                                $this->get_render_attribute_string('title'),
                                $title
                            ); ?>
                        </div>

                        <?php if (!empty($settings['description'])): ?>
                        <p><?php echo bdevs_element_kses_intermediate($settings['description']); ?></p>
                        <?php endif; ?>

                        <?php if (!empty($settings['slides'])): ?>
                        <div class="why__item-wrapper">
                            <?php foreach ($settings['slides'] as $slide): ?>
                           <div class="why__item-2 d-flex align-items-start">
                              <div class="why__icon-2 mr-30">
                                <?php if ($slide['type'] === 'image' && ($slide['image']['url'] || $slide['image']['id'])) :
                                    $this->get_render_attribute_string('image');
                                    $slide['hover_animation'] = 'disable-animation'; ?>
                                    <?php echo Group_Control_Image_Size::get_attachment_image_html($slide, 'thumbnail', 'image'); ?>
                                <?php elseif (!empty($slide['icon']) || !empty($slide['selected_icon']['value'])) : ?>
                                    <?php bdevs_element_render_icon($slide, 'icon', 'selected_icon'); ?>
                                <?php endif; ?>
                              </div>
                              <div class="why__content-2">
                                   <?php if (!empty($slide['title'])) : ?>
                                   <h3 class="why__title-2">
                                      <?php echo bdevs_element_kses_basic($slide['title']); ?>
                                   </h3>
                                   <?php endif; ?>

                                   <?php if (!empty($slide['title'])) : ?>
                                   <p><?php echo bdevs_element_kses_basic($slide['description']); ?></p>
                                   <?php endif; ?>
                              </div>
                           </div>
                            <?php endforeach; ?>
                        </div>
                        <?php endif; ?>
                     </div>
                  </div>
               </div>
            </div>
        </section>

    <?php elseif ($settings['design_style'] === 'style_3'):

        if (!empty($settings['bg_image']['id'])) {
            $bg_image = wp_get_attachment_image_url($settings['bg_image']['id'], $settings['thumbnail_size']);
        }

        $this->add_render_attribute('title', 'class', 'section__title section__title-2 bdevs-el-title');
        $this->add_render_attribute('title', 'data-wow-delay', '.4s');

        ?>

        <section class="about__area p-relative z-index-111">
            <div class="container">
               <div class="row">
                  <div class="col-xxl-7 col-xl-6 col-lg-6">
                    <?php if (!empty($bg_image)): ?>
                     <div class="about__thumb-3 w-img pr-20">
                        <img src="<?php echo esc_url($bg_image); ?>" alt="img">
                     </div>
                     <?php endif; ?>
                  </div>
                  <div class="col-xxl-5 col-xl-6 col-lg-6">
                     <div class="about__wrapper-2 pl-20 ">
                        <div class="section__title-wrapper-2 mb-25">
                            <?php if (!empty($settings['sub_title'])): ?>
                           <span class="section__title-pre section__title-pre-2 bdevs-el-subtitle"><?php echo bdevs_element_kses_intermediate($settings['sub_title']); ?></span>
                            <?php endif; ?>

                            <?php printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['title_tag']),
                                $this->get_render_attribute_string('title'),
                                $title
                            ); ?>
                        </div>
                        <?php if (!empty($settings['description'])): ?>
                        <p><?php echo bdevs_element_kses_intermediate($settings['description']); ?></p>
                        <?php endif; ?>

                        <?php if (!empty($settings['slides'])): ?>
                        <div class="about__item-wrapper">
                           <div class="row">
                              <?php foreach ($settings['slides'] as $slide): ?>
                              <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-6">
                                 <div class="about__item white-bg text-center mb-30">
                                    <div class="about__icon mb-15 elementor-repeater-item-<?php echo esc_attr($slide['_id']); ?>">
                                        <?php if ($slide['type'] === 'image' && ($slide['image']['url'] || $slide['image']['id'])) :
                                            $this->get_render_attribute_string('image');
                                            $slide['hover_animation'] = 'disable-animation'; ?>
                                            <?php echo Group_Control_Image_Size::get_attachment_image_html($slide, 'thumbnail', 'image'); ?>
                                        <?php elseif (!empty($slide['icon']) || !empty($slide['selected_icon']['value'])) : ?>
                                            <?php bdevs_element_render_icon($slide, 'icon', 'selected_icon'); ?>
                                        <?php endif; ?>
                                    </div>
                                    <div class="about__content-2">
                                        <?php if (!empty($slide['title'])) : ?>
                                       <h3 class="about__title-2">
                                          <a href="<?php echo esc_url( $slide['slide_link'] ); ?>"><?php echo bdevs_element_kses_basic($slide['title']); ?></a>
                                       </h3>
                                       <?php endif; ?>

                                       <?php if (!empty($slide['title'])) : ?>
                                       <p><?php echo bdevs_element_kses_basic($slide['description']); ?></p>
                                       <?php endif; ?>

                                       <a href="<?php echo esc_url( $slide['slide_link'] ); ?>" class="link-btn">
                                          <i class="far fa-arrow-right"></i>
                                          <i class="far fa-arrow-right"></i>
                                       </a>
                                    </div>
                                 </div>
                              </div>
                              <?php endforeach; ?>
                           </div>
                        </div>
                        <?php endif; ?>
                     </div>
                  </div>
               </div>
            </div>
        </section>

    <?php elseif ($settings['design_style'] === 'style_2'):
        if (!empty($settings['bg_image']['id'])) {
            $bg_image = wp_get_attachment_image_url($settings['bg_image']['id'], $settings['thumbnail_size']);
        }

        $this->add_render_attribute('title', 'class', 'section__title section__title-white bdevs-el-title');

        ?>

        <section class="why__area why__bg p-relative z-index-1">
            <div class="container-fluid">
               <div class="row">
                  <?php if (!empty($bg_image)): ?>
                  <div class="col-xxl-4 offset-xxl-2 col-xl-5">
                     <div class="why__thumb m-img ml-35">
                        <img src="<?php echo esc_url($bg_image); ?>" alt="img">
                     </div>
                  </div>
                  <?php endif; ?>

                  <div class="col-xxl-5 col-xl-7 col-lg-8 d-md-none d-xl-block">
                     <div class="why__wrapper pt-125 pb-125 pl-125">
                        <div class="section__title-wrapper mb-30">
                           <?php if (!empty($settings['sub_title'])): ?>
                           <span class="section__title-pre bdevs-el-subtitle"><?php echo bdevs_element_kses_intermediate($settings['sub_title']); ?></span>
                           <?php endif; ?>

                            <?php printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['title_tag']),
                                $this->get_render_attribute_string('title'),
                                $title
                            ); ?>
                        </div>

                        <?php if (!empty($settings['description'])): ?>
                        <p><?php echo bdevs_element_kses_intermediate($settings['description']); ?></p>
                        <?php endif; ?>

                        <?php if (!empty($settings['slides'])): ?>
                        <div class="why__inner d-sm-flex align-items-center">
                           <?php foreach ($settings['slides'] as $slide): ?>
                           <div class="why__item why__item-media text-center">
                              <div class="why__icon mb-15">
                                <?php if ($slide['type'] === 'image' && ($slide['image']['url'] || $slide['image']['id'])) :
                                    $this->get_render_attribute_string('image');
                                    $slide['hover_animation'] = 'disable-animation'; ?>
                                    <?php echo Group_Control_Image_Size::get_attachment_image_html($slide, 'thumbnail', 'image'); ?>
                                <?php elseif (!empty($slide['icon']) || !empty($slide['selected_icon']['value'])) : ?>
                                    <?php bdevs_element_render_icon($slide, 'icon', 'selected_icon'); ?>
                                <?php endif; ?>
                              </div>
                              <?php if (!empty($slide['title'])) : ?>
                              <div class="why__content">
                                 <h4 class="why__title"><?php echo bdevs_element_kses_basic($slide['title']); ?></h4>
                              </div>
                              <?php endif; ?>
                           </div>
                           <?php endforeach; ?>
                        </div>
                        <?php endif; ?>
                     </div>
                  </div>
               </div>
            </div>

            <div class="container d-none d-md-block d-xl-none">
               <div class="row">
                  <div class="col-12">
                     <div class="why__wrapper pt-125 pb-125 pl-125">
                        <div class="section__title-wrapper mb-30">
                           <?php if (!empty($settings['sub_title'])): ?>
                           <span class="section__title-pre bdevs-el-subtitle"><?php echo bdevs_element_kses_intermediate($settings['sub_title']); ?></span>
                           <?php endif; ?>

                            <?php printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['title_tag']),
                                $this->get_render_attribute_string('title'),
                                $title
                            ); ?>
                        </div>

                        <?php if (!empty($settings['description'])): ?>
                        <p><?php echo bdevs_element_kses_intermediate($settings['description']); ?></p>
                        <?php endif; ?>

                        <?php if (!empty($settings['slides'])): ?>
                        <div class="why__inner d-sm-flex align-items-center">
                           <?php foreach ($settings['slides'] as $slide): ?>
                           <div class="why__item text-center">
                              <div class="why__icon mb-15">
                                <?php if ($slide['type'] === 'image' && ($slide['image']['url'] || $slide['image']['id'])) :
                                    $this->get_render_attribute_string('image');
                                    $slide['hover_animation'] = 'disable-animation'; ?>
                                    <?php echo Group_Control_Image_Size::get_attachment_image_html($slide, 'thumbnail', 'image'); ?>
                                <?php elseif (!empty($slide['icon']) || !empty($slide['selected_icon']['value'])) : ?>
                                    <?php bdevs_element_render_icon($slide, 'icon', 'selected_icon'); ?>
                                <?php endif; ?>
                              </div>
                              <?php if (!empty($slide['title'])) : ?>
                              <div class="why__content">
                                 <h4 class="why__title"><?php echo bdevs_element_kses_basic($slide['title']); ?></h4>
                              </div>
                              <?php endif; ?>
                           </div>
                           <?php endforeach; ?>
                        </div>
                        <?php endif; ?>

                     </div>
                  </div>
               </div>
            </div>
        </section>

    <?php else:
        if (!empty($settings['bg_image']['id'])) {
            $bg_image = wp_get_attachment_image_url($settings['bg_image']['id'], $settings['thumbnail_size']);
        }
        if (!empty($settings['image2']['id'])) {
            $image2 = wp_get_attachment_image_url($settings['image2']['id'], $settings['thumbnail_size']);
        }
        if (!empty($settings['author_img']['id'])) {
            $author_img = wp_get_attachment_image_url($settings['author_img']['id'], $settings['thumbnail_size']);
        }
        if (!empty($settings['signature_img']['id'])) {
            $signature_img = wp_get_attachment_image_url($settings['signature_img']['id'], $settings['thumbnail_size']);
        }

        $this->add_render_attribute('title', 'class', 'bdevs-el-title section__title');

        ?>

        <section class="about__area">
            <div class="container">
               <div class="row">
                  <?php if (!empty($bg_image)): ?>
                  <div class="col-xxl-7 col-xl-6 col-lg-5">
                     <div class="about__thumb about__triangle p-relative">
                        <div class="about__thumb-1 w-img">
                           <img src="<?php echo esc_url($bg_image); ?>" alt="img">
                        </div>
                        <div class="about__thumb-2 text-end">
                           <img src="<?php echo esc_url($image2); ?>" alt="img">
                        </div>
                     </div>
                  </div>
                  <?php endif; ?>

                  <div class="col-xxl-5 col-xl-6 col-lg-7">
                     <div class="about__content pl-60 pt-25 bdevs-el-content">
                        <div class="section__title-wrapper mb-25">
                           <?php if (!empty($settings['sub_title'])): ?>
                           <span class="section__title-pre bdevs-el-subtitle"><?php echo bdevs_element_kses_intermediate($settings['sub_title']); ?></span>
                           <?php endif; ?>

                            <?php printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['title_tag']),
                                $this->get_render_attribute_string('title'),
                                $title
                            ); ?>
                        </div>

                        <?php if (!empty($settings['description'])): ?>
                        <p class="bold-text"><?php echo bdevs_element_kses_intermediate($settings['description']); ?> </p>
                        <?php endif; ?>

                        <?php if (!empty($settings['description2'])): ?>
                        <p><?php echo bdevs_element_kses_intermediate($settings['description2']); ?></p>
                        <?php endif; ?>

                        <div class="about__author d-sm-flex align-items-center">
                           <div class="about__author-content d-flex align-items-center mr-35">
                              <?php if (!empty($author_img)): ?>
                              <div class="about__author-avater mr-20">
                                 <img src="<?php echo esc_url($author_img); ?>" alt="img">
                              </div>
                              <?php endif; ?>

                              <div class="about__author-info">
                                <?php if (!empty($settings['author_name'])): ?>
                                 <h3><?php echo bdevs_element_kses_intermediate($settings['author_name']); ?></h3>
                                 <?php endif; ?>

                                 <?php if (!empty($settings['author_designation'])): ?>
                                 <span><?php echo bdevs_element_kses_intermediate($settings['author_designation']); ?></span>
                                 <?php endif; ?>
                              </div>
                           </div>

                           <?php if (!empty($signature_img)): ?>
                           <div class="about__author-signature">
                              <img src="<?php echo esc_url($signature_img); ?>" alt="img">
                           </div>
                           <?php endif; ?>
                        </div>
                     </div>
                  </div>
               </div>
            </div>
        </section>

    <?php endif; ?>
        <?php
    }
}
