<?php
/**
 * roxce functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package roxce
 */

if ( ! function_exists( 'roxce_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function roxce_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on roxce, use a find and replace
		 * to change 'roxce' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'roxce', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'main-menu' => esc_html__( 'Main Menu', 'roxce' )
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'roxce_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		//Enable custom header
		add_theme_support('custom-header');


		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		/**
		 * Enable suporrt for Post Formats
		 *
		 * see: https://codex.wordpress.org/Post_Formats
		 */
		add_theme_support( 'post-formats', array(
			'image',
			'audio',
			'video',
			'gallery',
			'quote',
		) );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		// Add support for editor styles.
		add_theme_support( 'editor-styles' );

		// Add support for responsive embedded content.
		add_theme_support( 'responsive-embeds' );

		remove_theme_support( 'widgets-block-editor' );


		add_image_size( 'roxce-case-details', 1170, 600, array('center','center') );
		add_image_size( 'roxce-post-thumb', 500, 350, array('center','center') );
		add_image_size( 'roxce-case-thumb', 700, 544, array('center','center') );
	}
endif;
add_action( 'after_setup_theme', 'roxce_setup' );


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function roxce_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'roxce_content_width', 640 );
}
add_action( 'after_setup_theme', 'roxce_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function roxce_widgets_init() {

	$footer_style_2_switch = get_theme_mod('footer_style_2_switch', false );
	$footer_style_3_switch = get_theme_mod('footer_style_3_switch', false );

	/**
	* blog sidebar
	*/
	register_sidebar( array(
		'name'          => esc_html__( 'Blog Sidebar', 'roxce' ),
		'id'            => 'blog-sidebar',
		'before_widget' => '<div id="%1$s" class="sidebar__widget mb-40 grey-bg %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="sidebar__widget-title mb-30">',
		'after_title'   => '</h3>',
	) );

	$footer_widgets = get_theme_mod('footer_widget_number', 4);

    // default footer 
	for( $num=1; $num <= $footer_widgets; $num++ ) {
		register_sidebar( array(
			'name'          => esc_html__( 'Footer '. $num, 'roxce'),
			'id'            => 'footer-'. $num,
			'description'   => esc_html__( 'Footer '. $num, 'roxce' ),
			'before_widget' => '<div id="%1$s" class="footer__widget mb-50 footer-col-'.$num.' %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="footer__widget-title">',
			'after_title'   => '</h3>',
		) );			
	}


	// footer 2
	if ( $footer_style_2_switch ) {
		for( $num=1; $num <= $footer_widgets; $num++ ) {
			register_sidebar( array(
				'name'          => esc_html__( 'Footer Style 2: '. $num, 'roxce'),
				'id'            => 'footer-2-'. $num,
				'description'   => esc_html__( 'Footer Style 2: '. $num, 'roxce' ),
				'before_widget' => '<div id="%1$s" class="footer__widget mb-50 footer-col-2-'.$num.' %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h3 class="footer__widget-title">',
				'after_title'   => '</h3>',
			) );			
		}
	}


	// footer 3
	if ( $footer_style_3_switch ) {
		for( $num=1; $num <= $footer_widgets; $num++ ) {
			register_sidebar( array(
				'name'          => esc_html__( 'Footer Style 3: '. $num, 'roxce'),
				'id'            => 'footer-3-'. $num,
				'description'   => esc_html__( 'Footer Style 3: '. $num, 'roxce' ),
				'before_widget' => '<div id="%1$s" class="footer__widget mb-50 footer-col-3-'.$num.' %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h3 class="footer__widget-title footer__widget-title-3">',
				'after_title'   => '</h3>',
			) );			
		}
	}

	/**
	* Service Widget
	*/
	register_sidebar(
		array(
			'name' 			=> esc_html__( 'Service Sidebar', 'roxce' ),
			'id' 			=> 'services-sidebar',
			'description' 	=> esc_html__( 'Widgets in this area will be shown on Service Details Sidebar.', 'roxce' ),
			'before_widget' => '<div class="services__widget mb-30 %2$s"><div class="services__widget-content">',
			'after_widget' 	=> '</div></div>',
			'before_title' 	=> '<h4 class="bs-widget-title mb-30">',
			'after_title' 	=> '</h4>',
		)
	);
	/**
	* blog sidebar
	*/
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar Instagram Sidebar', 'roxce' ),
		'id'            => 'insta-sidebar-widget',
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '',
		'after_title'   => '',
	) );
}
add_action( 'widgets_init', 'roxce_widgets_init' );

/**
 * Enqueue scripts and styles.
 */

define('ROXCE_THEME_DIR', get_template_directory());
define('ROXCE_THEME_URI', get_template_directory_uri());
define('ROXCE_THEME_CSS_DIR', ROXCE_THEME_URI . '/assets/css/');
define('ROXCE_THEME_JS_DIR', ROXCE_THEME_URI . '/assets/js/');
define('ROXCE_THEME_INC', ROXCE_THEME_DIR . '/inc/');

/** 
 * roxce_scripts description
 * @return [type] [description]
 */
function roxce_scripts() {

	/**
	* all css files
	*/

	wp_enqueue_style( 'roxce-fonts', roxce_fonts_url(), array(), '1.0.0' );
	if( is_rtl() ){
        wp_enqueue_style( 'bootstrap-rtl', ROXCE_THEME_CSS_DIR.'bootstrap.rtl.min.css', array() );
    }else{
        wp_enqueue_style( 'bootstrap', ROXCE_THEME_CSS_DIR.'bootstrap.min.css', array() );
    }
	
	wp_enqueue_style( 'meanmenu', ROXCE_THEME_CSS_DIR.'meanmenu.css', array() );
	wp_enqueue_style( 'animate', ROXCE_THEME_CSS_DIR.'animate.min.css', array() );
	wp_enqueue_style( 'owl-carousel', ROXCE_THEME_CSS_DIR.'owl.carousel.min.css', array() );
	wp_enqueue_style( 'swiper-bundle', ROXCE_THEME_CSS_DIR.'swiper-bundle.css', array() );
	wp_enqueue_style( 'backtotop', ROXCE_THEME_CSS_DIR.'backToTop.css', array() );
	wp_enqueue_style( 'magnific-popup', ROXCE_THEME_CSS_DIR.'magnific-popup.css', array() );
	wp_enqueue_style( 'nice-select', ROXCE_THEME_CSS_DIR.'nice-select.css', array() );
	wp_enqueue_style( 'circularprogressbar', ROXCE_THEME_CSS_DIR.'circularProgressBar.css', array() );
	wp_enqueue_style( 'fontawesome5pro', ROXCE_THEME_CSS_DIR.'fontAwesome5Pro.css', array() );
	wp_enqueue_style( 'preloader', ROXCE_THEME_CSS_DIR.'preloader.css', array() );
	wp_enqueue_style( 'flaticon', ROXCE_THEME_CSS_DIR.'flaticon.css', array() );
	wp_enqueue_style( 'default', ROXCE_THEME_CSS_DIR.'default.css', array() );
	wp_enqueue_style( 'roxce-core', ROXCE_THEME_CSS_DIR.'roxce-core.css', array(), time() );
	wp_enqueue_style( 'roxce-unit', ROXCE_THEME_CSS_DIR.'roxce-unit.css', array(), time() );
	wp_enqueue_style( 'roxce-style', get_stylesheet_uri() );
	wp_enqueue_style( 'roxce-responsive', ROXCE_THEME_CSS_DIR.'responsive.css', array() );
 
	// all js
	wp_enqueue_script( 'bootstrap-bundle', ROXCE_THEME_JS_DIR.'bootstrap.bundle.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'meanmenu', ROXCE_THEME_JS_DIR.'meanmenu.js', array('jquery'), '', true );
	wp_enqueue_script( 'swiper-bundle', ROXCE_THEME_JS_DIR.'swiper-bundle.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'owl-carousel', ROXCE_THEME_JS_DIR.'owl.carousel.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'magnific-popup', ROXCE_THEME_JS_DIR.'magnific-popup.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'parallax', ROXCE_THEME_JS_DIR.'parallax.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'backtotop', ROXCE_THEME_JS_DIR.'backToTop.js', array('jquery'), '', true );
	wp_enqueue_script( 'nice-select', ROXCE_THEME_JS_DIR.'nice-select.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'counterup', ROXCE_THEME_JS_DIR.'counterup.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'jquery-appear', ROXCE_THEME_JS_DIR.'jquery.appear.js', array('jquery'), '', true );
	wp_enqueue_script( 'jquery-knob', ROXCE_THEME_JS_DIR.'jquery.knob.js', array('jquery'), '', true );
	wp_enqueue_script( 'wow', ROXCE_THEME_JS_DIR.'wow.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'isotope-pkgd', ROXCE_THEME_JS_DIR.'isotope.pkgd.min.js', array('imagesloaded'), '', true );
	wp_enqueue_script( 'waypoints', ROXCE_THEME_JS_DIR.'waypoints.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'circularprogressbar', ROXCE_THEME_JS_DIR.'circularProgressBar.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'roxce-main', ROXCE_THEME_JS_DIR.'main.js', array('jquery'), false, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

}
add_action( 'wp_enqueue_scripts', 'roxce_scripts' );

/*
Register Fonts
*/
/*
Register Fonts
*/

function roxce_fonts_url() {
    $font_url = '';

    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Google font: on or off', 'roxce' ) ) {
        $font_url = 'https://fonts.googleapis.com/css2?'. urlencode('family=Hind:wght@400;500;600;700&family=Rubik:wght@400;500;600;700&display=swap');

    }
    return $font_url;
}

// wp_body_open
if ( ! function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
            do_action( 'wp_body_open' );
    }
}

/**
 * Implement the Custom Header feature.
 */
require ROXCE_THEME_INC . 'custom-header.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require ROXCE_THEME_INC . 'template-functions.php';

/**
 * Custom template helper function for this theme.
 */
require ROXCE_THEME_INC . 'template-helper.php';



/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require ROXCE_THEME_INC . 'jetpack.php';
}

/**
* include roxce functions file
*/
require_once ROXCE_THEME_INC . 'class-breadcrumb.php';
require_once ROXCE_THEME_INC . 'class-navwalker.php';
require_once ROXCE_THEME_INC . 'class-roxce-kirki.php';
require_once ROXCE_THEME_INC . 'kirki-customizer.php';
require_once ROXCE_THEME_INC . 'class-tgm-plugin-activation.php';
require_once ROXCE_THEME_INC . 'add_plugin.php';



/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function roxce_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'roxce_pingback_header' );


/**
*
* comment section
*
*/
add_filter('comment_form_default_fields', 'roxce_comment_form_default_fields_func');

function roxce_comment_form_default_fields_func($default){

	$default['author'] = '<div class="row">
    <div class="col-xl-6 col-md-6">
    	<div class="post-input">
        	<input type="text" name="author" placeholder="'.esc_attr__('Your Name','roxce').'">
        </div>
    </div>';
	$default['email'] = '<div class="col-xl-6 col-md-6">
		<div class="post-input">
        <input type="text" name="email" placeholder="'.esc_attr__('Your Email','roxce').'">
    	</div>
    </div>';
	// $default['url'] = '';
	$defaults['comment_field'] = '';

	$default['url'] = '<div class="col-xl-12">
		<div class="post-input">
        <input type="text" name="url" placeholder="'.esc_attr__('Website','roxce').'">
    	</div>
    </div>';
	return $default;
}

add_action( 'comment_form_top', 'roxce_add_comments_textarea' );
function roxce_add_comments_textarea()
{
	if( !is_user_logged_in() ){
    echo '<div class="row"><div class="col-xl-12"><div class="post-input"><textarea id="comment" name="comment" cols="60" rows="6" placeholder="'.esc_attr__('Write your comment here...','roxce').'" aria-required="true"></textarea></div></div></div>';
	}
}

add_filter('comment_form_defaults', 'roxce_comment_form_defaults_func');

function roxce_comment_form_defaults_func($info){
	if( !is_user_logged_in() ){
		$info['comment_field'] = '';
		$info['submit_field'] = '%1$s %2$s</div>';
	}else {
		$info['comment_field'] = '<div class="post-input"><textarea id="comment" name="comment" cols="30" rows="10" placeholder="'.esc_attr__('Comment *','roxce').'"></textarea>';
        $info['submit_field'] = '%1$s %2$s</div>';
	}


	$info['submit_button'] = '<div class="col-xl-12"><button class="r-btn r-btn-yellow" type="submit">'.esc_html__('Post Comment','roxce').' </button></div>';

	$info['title_reply_before'] = '<div class="post-comments-title">
                                        <h2>';
	$info['title_reply_after'] = '</h2></div>';
	$info['comment_notes_before'] = '';

	return $info;
}

if( !function_exists('roxce_comment') ) {
	function roxce_comment($comment, $args, $depth) {
		$GLOBAL['comment'] = $comment;
		extract($args, EXTR_SKIP);
		$args['reply_text'] = '<i class="fal fa-reply"></i> Reply';
		$replayClass = 'comment-depth-' . esc_attr($depth);
		?>
			<li id="comment-<?php comment_ID(); ?>">
				<div class="comments-box">
					<div class="comments-avatar">
						<?php print get_avatar($comment, 102, null, null, array('class'=> array())); ?>
					</div>
					<div class="comments-text">
						<div class="avatar-name">
							<h5><?php print get_comment_author_link(); ?></h5>
							<span><?php comment_time( get_option('date_format') ); ?></span>
						</div>
						<?php comment_text(); ?>
						<?php comment_reply_link( array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth'] ))); ?>
					</div>
				</div>
		<?php
	}
}



/**
* shortcode supports for removing extra p, spance etc
*
*/
add_filter( 'the_content', 'roxce_shortcode_extra_content_remove' );
/**
 * Filters the content to remove any extra paragraph or break tags
 * caused by shortcodes.
 *
 * @since 1.0.0
 *
 * @param string $content  String of HTML content.
 * @return string $content Amended string of HTML content.
 */
function roxce_shortcode_extra_content_remove( $content ) {

    $array = array(
        '<p>['    => '[',
        ']</p>'   => ']',
        ']<br />' => ']'
    );
    return strtr( $content, $array );

}


// roxce_search_filter_form
if( !function_exists('roxce_search_filter_form')) {
  function roxce_search_filter_form( $form ) {
    
    $form = sprintf( 
    	'<div class="sidebar--widget__search"><form class="sidebar-search-form" action="%s" method="get">
      	<input type="text" value="%s" required name="s" placeholder="%s">
      	<button type="submit"> <i class="far fa-search"></i>  </button>
		</form></div>',
		esc_url( home_url('/') ),
		esc_attr( get_search_query() ),
		esc_html__('Search','roxce')
	);

    return $form;
  }
  add_filter( 'get_search_form','roxce_search_filter_form');
}

add_action('admin_enqueue_scripts', 'roxce_admin_custom_scripts');

function roxce_admin_custom_scripts() {
	wp_enqueue_media();
	wp_register_script('roxce-admin-custom', get_template_directory_uri().'/inc/js/admin_custom.js', array('jquery'), '', true);
	wp_enqueue_script('roxce-admin-custom');
}

function roxce_elementor_library() {
	$pageslist = get_posts(
		array(
			'post_type'      => 'elementor_library',
			'posts_per_page' => -1,
		)
	);
	$pagearray = array();
	if ( ! empty( $pageslist ) ) {
		foreach ( $pageslist as $page ) {
			$pagearray[ $page->ID ] = $page->post_title;
		}
	}
	return $pagearray;
}